## Landscape of kinase activity responses under perturbation

To extensively study the heterogeneity and specificity of the human signaling response, we compiled and standardized 41 quantitative studies reporting the relative changes in phosphopeptide abundance after perturbation (see Materials and Methods). From the detected peptides, we collected identifications for 119,710 phosphosites in 12,505 proteins, 63% of which already reported in phosphosite databases (Fig EV1). For these sites, we normalized a total of 2,940,379 quantitative changes in phosphopeptide abundance in a panel of 435 biological conditions covering a broad spectrum of perturbations including targeted kinase inhibition, induced hESC differentiation or cell cycle progression, among many others (Appendix Fig S1, Table EV1). Only 1% of all phosphorylated sites were reported in more than 60% of the studies, whereas 52% of the sites were quantified in one single study (Fig EV1). The observed data sparsity, a common problem in shotgun proteomics, is frequently derived from the accumulation of technical and biological variants. To prevent the aggregation of false positives, only phosphosites observed in two or more independent studies were considered in downstream analysis.

In order to circumvent the problem of incomplete coverage due to the different sets of quantified sites in each study, we avoid analysing individual phosphosites. Instead, we predicted the changes in kinase activity by testing the enrichment on differentially regulated phosphosites among the known substrates of each kinase (Fig 1A). Using a modified version of the weighted Kinase Set Enrichment Analysis (KSEA) \cite{23532336,16199517}, we quantified the regulation of 215 kinases in a range between 10 to 399 perturbations (Fig 1A, Table EV2, Materials and Methods). To verify the ability of KSEA to quantitatively measure the changes in kinase regulation, we performed a series of benchmark tests based on prior knowledge.

The known mechanism of action of certain biological processes or compounds suggests different perturbations in which specific kinase regulation is expected. For instance, the ATM (ataxia telangiectasia, mutated) and ATR (ATM and Rad3-related) kinases display direct regulation corroborated by the KSEA activities under DNA-damaging conditions (Fig 1B). Similarly, the kinases in the MAPK/Erk pathway accurately display activation 10 minutes after EGF stimulation (Fig 1B). Conversely, the KSEA estimates also report decrease in kinase activities as in the case of the Epidermal Growth Factor Receptor (EGFR) inhibition mediated by erlotinib and gefitinib or MTOR inhibition by Torin1 (Fig 1B). Overall, the KSEA activity shows no predictive power to discriminate expected regulation in 132 kinase-condition pairs (Fig 1C, Table EV3, area under ROC curve=0.75). 

To further validate the kinase regulation inference, we compared the KSEA activities across conditions with the corresponding changes in kinase regulatory phosphosites collected in the atlas. For example, phosphorylation of the activation loop residue Threonine 287 (T287), known to result in an increased catalytic activity of AURKA, presents a significant co-regulation with the AURKA KSEA activity (Spearman's \(\rho = 0.6\), \(p=0.02\)). Phosphorylation of T287 and KSEA activity derived from AURKA substrates are both decreased as AURKA inhibitor MLN8054 concentration increases (Fig 1D). Overall, we observe a significantly higher correlation between the KSEA activities and the changes in kinase auto-regulatory sites (Student's t-test, \(p=1.7\times10^{-4}\)) (Fig 1E). Finally, we compared the kinase regulation with those assayed in a previous study using phospho-specific antibodies under similar conditions \cite{26901648}. As an example, the KSEA activities 10 mins after EGF stimulation significantly correlate (\(\rho=0.53\), \(p=0.008\)) with the antibody-based quantified phospho-regulation 15 minutes after EGF stimulation (Fig 1F). Despite the differences of both assays, the profile of inferred changes based on 26 phospho-dependent antibodies and the MS-based KSEA activities for the equivalent kinases present significantly higher correlations when cells are stimulated with similar EGFR activating conditions (Fig 1G, Student's one-sided t-test \(p=2.7\times10^{-5}\), Appendix Fig S2).

Together, these results not only validate the activity inference for individual kinases but strongly suggest the profile of kinase activity changes can serve as molecular barcodes of the cellular signaling state.